@@ -15,6 +15,7 @@ import mlflow.store.artifact.cli
 from mlflow import tracking
 from mlflow.entities.lifecycle_stage import LifecycleStage
 from mlflow.exceptions import MlflowException
+from mlflow.server.handler_utils import ensure_dir
 from mlflow.store.artifact.artifact_repository_registry import get_artifact_repository
 from mlflow.store.tracking import (
     DEFAULT_ARTIFACTS_URI,
@@ -478,7 +479,8 @@ def gc(backend_store_uri, run_ids):
                 "Run % is not in `deleted` lifecycle stage. Only runs in "
                 "`deleted` lifecycle stage can be deleted." % run_id
             )
-        artifact_repo = get_artifact_repository(run.info.artifact_uri)
+        # TODO (chiragjn): ensure_dir is a temporary hack. Better to migrate paths in db
+        artifact_repo = get_artifact_repository(ensure_dir(run.info.artifact_uri))
         artifact_repo.delete_artifacts()
         backend_store.hard_delete_run(run_id)
         print("Run with ID %s has been permanently deleted." % str(run_id))
