@@ -21,7 +21,6 @@ class Experiment(_MLflowObject):
         lifecycle_stage,
         tags=None,
         creator_user_id=None,
-        owner_subject_id=None,
         num_runs=None,
         num_user_collaborators=None,
         description=None,
@@ -36,7 +35,6 @@ class Experiment(_MLflowObject):
         self._lifecycle_stage = lifecycle_stage
         self._tags = {tag.key: tag.value for tag in (tags or [])}
         self._creator_user_id = creator_user_id
-        self._owner_subject_id = owner_subject_id
         self._num_runs = num_runs
         self._num_user_collaborators = num_user_collaborators
         self._description = description
@@ -72,10 +70,6 @@ class Experiment(_MLflowObject):
         """user_id of the creator of the experiment"""
         return self._creator_user_id
 
-    @property
-    def owner_subject_id(self):
-        return self._owner_subject_id
-
     @property
     def num_runs(self):
         return self._num_runs
@@ -118,7 +112,6 @@ class Experiment(_MLflowObject):
             proto.artifact_location,
             proto.lifecycle_stage,
             creator_user_id=proto.creator_user_id,
-            owner_subject_id=proto.owner_subject_id,
             num_runs=proto.num_runs,
             num_user_collaborators=proto.num_user_collaborators,
             description=proto.description,
@@ -140,7 +133,6 @@ class Experiment(_MLflowObject):
             [ProtoExperimentTag(key=key, value=val) for key, val in self._tags.items()]
         )
         experiment.creator_user_id = self.creator_user_id
-        experiment.owner_subject_id = self.owner_subject_id
         experiment.num_runs = self.num_runs
         experiment.num_user_collaborators = self.num_user_collaborators
         experiment.description = self.description or ""
