@@ -1,7 +1,7 @@
 import datetime
 import posixpath
 import uuid
-from typing import Any, Dict, Optional, Tuple
+from typing import Any, Dict, List, Optional, Tuple
 
 from pydantic import BaseModel, Field, constr
 
@@ -16,9 +16,7 @@ from mlflow.protos import mlfoundry_artifacts_pb2 as mlfa_pb2
 from mlflow.protos.databricks_pb2 import INVALID_PARAMETER_VALUE
 from mlflow.utils.proto_json_utils import get_field_if_set
 
-_ARTIFACT_FQN_FORMAT = (
-    "{artifact_type}:{tenant_name}/{experiment_owner_name}/{experiment_name}/{artifact_name}"
-)
+_ARTIFACT_FQN_FORMAT = "{artifact_type}:{tenant_name}/{experiment_name}/{artifact_name}"
 _ARTIFACT_VERSION_FQN_FORMAT = "{artifact_fqn}:{version}"
 
 _ARTIFACT_VERSION_USAGE_CODE_SNIPPET = """import mlfoundry as mlf
@@ -40,14 +38,11 @@ class BaseArtifactMixin(BaseModel):
     def generate_fqn(
         experiment: Experiment, artifact_type: ArtifactType, artifact_name: str
     ) -> str:
-        if not experiment.tenant_name or not experiment.owner_subject_id:
-            raise ValueError(
-                f"Attributes `tenant_name` and `owner_subject_id` on `experiment` cannot be None"
-            )
+        if not experiment.tenant_name:
+            raise ValueError(f"Attributes `tenant_name` on `experiment` cannot be None")
         return _ARTIFACT_FQN_FORMAT.format(
             artifact_type=artifact_type.value,
             tenant_name=experiment.tenant_name,
-            experiment_owner_name=experiment.owner_subject_id,
             experiment_name=experiment.name,
             artifact_name=artifact_name,
         )
@@ -79,6 +74,7 @@ class Artifact(BaseArtifactMixin):
     artifact_storage_root: str
     created_by: constr(max_length=256)
     latest_version: Optional["ArtifactVersion"] = None
+    run_steps: List[int] = Field(default_factory=list)
 
     created_at: datetime.datetime
     updated_at: datetime.datetime
@@ -95,6 +91,7 @@ class Artifact(BaseArtifactMixin):
             created_by=self.created_by,
             created_at=self.created_at.astimezone(tz=datetime.timezone.utc).isoformat(),
             updated_at=self.updated_at.astimezone(tz=datetime.timezone.utc).isoformat(),
+            run_steps=self.run_steps,
         )
         if self.latest_version:
             message.latest_version.MergeFrom(self.latest_version.to_proto())
@@ -118,6 +115,7 @@ class Artifact(BaseArtifactMixin):
             latest_version=latest_version,
             created_at=datetime.datetime.fromisoformat(message.created_at),
             updated_at=datetime.datetime.fromisoformat(message.updated_at),
+            run_steps=[rs for rs in message.run_steps],
         )
 
 
@@ -151,11 +149,12 @@ class ArtifactVersion(BaseArtifactVersionMixin):
         orm_mode = True
         validate_assignment = True
         use_enum_values = True
-        allow_mutation = False
+        allow_mutation = True
         smart_union = True
 
     id: uuid.UUID
     artifact_id: uuid.UUID
+    artifact_name: str  # from relation
     artifact_fqn: str  # from relation
     experiment_id: int  # from relation
     version: int
@@ -165,10 +164,11 @@ class ArtifactVersion(BaseArtifactVersionMixin):
     description: Optional[constr(max_length=1024)] = None
     status: ArtifactVersionStatus
     step: int = 0
-    run_id: Optional[str]  # from events
+    run_id: str  # also stored in events
     created_by: str
     created_at: datetime.datetime
     updated_at: datetime.datetime
+    internal_metadata: Optional[Dict[str, Any]] = None
 
     @property
     def fqn(self) -> str:
@@ -184,6 +184,7 @@ class ArtifactVersion(BaseArtifactVersionMixin):
         return mlfa_pb2.ArtifactVersion(
             id=str(self.id),
             artifact_id=str(self.artifact_id),
+            artifact_name=self.artifact_name,
             artifact_fqn=self.artifact_fqn,
             experiment_id=str(self.experiment_id),
             version=self.version,
@@ -199,6 +200,7 @@ class ArtifactVersion(BaseArtifactVersionMixin):
             created_by=self.created_by,
             created_at=self.created_at.astimezone(tz=datetime.timezone.utc).isoformat(),
             updated_at=self.updated_at.astimezone(tz=datetime.timezone.utc).isoformat(),
+            internal_metadata=utils.dict_to_proto(self.internal_metadata or {}),
         )
 
     @classmethod
@@ -206,6 +208,9 @@ class ArtifactVersion(BaseArtifactVersionMixin):
         artifact_metadata = get_field_if_set(message, "artifact_metadata", default={})
         if artifact_metadata:
             artifact_metadata = utils.dict_from_proto(artifact_metadata)
+        internal_metadata = get_field_if_set(message, "internal_metadata", default={})
+        if internal_metadata:
+            internal_metadata = utils.dict_from_proto(internal_metadata)
         data_path = get_field_if_set(message, "data_path", default=None)
         description = get_field_if_set(message, "description", default=None)
         step = get_field_if_set(message, "step", default=0)
@@ -213,6 +218,7 @@ class ArtifactVersion(BaseArtifactVersionMixin):
         return cls(
             id=uuid.UUID(message.id),
             artifact_id=uuid.UUID(message.artifact_id),
+            artifact_name=message.artifact_name,
             artifact_fqn=message.artifact_fqn,
             experiment_id=int(message.experiment_id),
             version=message.version,
@@ -226,6 +232,7 @@ class ArtifactVersion(BaseArtifactVersionMixin):
             created_by=message.created_by,
             created_at=datetime.datetime.fromisoformat(message.created_at),
             updated_at=datetime.datetime.fromisoformat(message.updated_at),
+            internal_metadata=internal_metadata,
         )
 
 
