@@ -5,6 +5,7 @@ from typing import Any, Dict, List, Optional
 
 from pydantic import BaseModel, Field, constr, root_validator
 
+from mlflow.entities.experiment import Experiment
 from mlflow.entities.metric import Metric
 from mlflow.entities.mlfoundry_artifacts import utils
 from mlflow.entities.mlfoundry_artifacts.artifact import (
@@ -47,9 +48,11 @@ class Model(BaseArtifactMixin):
         use_enum_values = True
         allow_mutation = False
         smart_union = True
+        arbitrary_types_allowed = True
 
     id: uuid.UUID
     experiment_id: int
+    experiment: Optional[Experiment] = None
     type: ArtifactType
     name: constr(regex=r"^[A-Za-z0-9_\-]+$", max_length=256)
     fqn: str
@@ -59,11 +62,13 @@ class Model(BaseArtifactMixin):
     latest_version: Optional["ModelVersion"] = None
     created_at: datetime.datetime
     updated_at: datetime.datetime
+    monitoring_enabled: bool = False
 
     def to_proto(self) -> mlfa_pb2.Model:
         message = mlfa_pb2.Model(
             id=str(self.id),
             experiment_id=str(self.experiment_id),
+            experiment=self.experiment.to_proto() if self.experiment else None,
             type=ArtifactType(self.type).to_proto(),
             name=self.name,
             fqn=self.fqn,
@@ -72,6 +77,7 @@ class Model(BaseArtifactMixin):
             created_by=self.created_by,
             created_at=self.created_at.astimezone(tz=datetime.timezone.utc).isoformat(),
             updated_at=self.updated_at.astimezone(tz=datetime.timezone.utc).isoformat(),
+            monitoring_enabled=self.monitoring_enabled,
         )
         if self.latest_version:
             message.latest_version.MergeFrom(self.latest_version.to_proto())
@@ -86,6 +92,7 @@ class Model(BaseArtifactMixin):
         return cls(
             id=uuid.UUID(message.id),
             experiment_id=int(message.experiment_id),
+            experiment=Experiment.from_proto(message.experiment),
             type=ArtifactType.from_proto(message.type),
             name=message.name,
             fqn=message.fqn,
@@ -95,6 +102,7 @@ class Model(BaseArtifactMixin):
             latest_version=latest_version,
             created_at=datetime.datetime.fromisoformat(message.created_at),
             updated_at=datetime.datetime.fromisoformat(message.updated_at),
+            monitoring_enabled=message.monitoring_enabled,
         )
 
 
@@ -283,6 +291,7 @@ class ModelVersion(BaseArtifactVersionMixin):
 
     id: uuid.UUID
     model_id: uuid.UUID
+    model_name: str  # from relation
     model_fqn: str  # from relation
     experiment_id: int  # from relation
     version: int
@@ -359,6 +368,7 @@ class ModelVersion(BaseArtifactVersionMixin):
         model_version = mlfa_pb2.ModelVersion(
             id=str(self.id),
             model_id=str(self.model_id),
+            model_name=self.model_name,
             model_fqn=self.model_fqn,
             experiment_id=str(self.experiment_id),
             version=self.version,
@@ -404,6 +414,7 @@ class ModelVersion(BaseArtifactVersionMixin):
             id=uuid.UUID(message.id),
             metrics=metrics,
             model_id=uuid.UUID(message.model_id),
+            model_name=message.model_name,
             model_fqn=message.model_fqn,
             experiment_id=int(message.experiment_id),
             version=message.version,
