@@ -137,6 +137,15 @@ class GCSArtifactRepository(ArtifactRepository):
         gcs_bucket = self._get_bucket(bucket)
         gcs_bucket.blob(remote_full_path).download_to_filename(local_path)
 
+    def get_artifact_contents(self, remote_path: str):
+        self._ensure_valid_credentials()
+        (bucket, remote_root_path) = self.parse_gcs_uri(self.artifact_uri)
+        remote_full_path = posixpath.join(remote_root_path, remote_path)
+        gcs_bucket = self._get_bucket(bucket)
+        # TODO (nikp1172) download_as_bytes will not work for large files,
+        #   use https://cloud.google.com/python/docs/reference/storage/latest/google.cloud.storage.blob.Blob#google_cloud_storage_blob_Blob_open
+        return gcs_bucket.blob(remote_full_path).download_as_bytes()
+
     @staticmethod
     def _verify_listed_object_contains_artifact_path_prefix(listed_object_path, artifact_path):
         if not listed_object_path.startswith(artifact_path):
