@@ -202,6 +202,13 @@ class S3ArtifactRepository(ArtifactRepository):
         s3_client = self._get_s3_client()
         s3_client.download_file(bucket, s3_full_path, local_path)
 
+    def get_artifact_contents(self, remote_path: str):
+        (bucket, s3_root_path) = data.parse_s3_uri(self.artifact_uri)
+        s3_full_path = posixpath.join(s3_root_path, remote_path)
+        s3_client = self._get_s3_client()
+        response = s3_client.get_object(Bucket=bucket, Key=s3_full_path)
+        return response["Body"].read()
+
     def delete_artifacts(self, artifact_path=None):
         # TODO (chiragjn): This is not the most efficient way to bulk delete things, we need to async this
         #       Futhermore `list_objects` may not return everything above a certain number of files
