@@ -106,7 +106,7 @@ class AbstractStore:
         pass
 
     @abstractmethod
-    def get_experiment(self, experiment_id):
+    def get_experiment(self, experiment_id, view_type=ViewType.ALL):
         """
         Fetch the experiment by ID from the backend store.
 
@@ -121,7 +121,6 @@ class AbstractStore:
     def get_experiment_by_name(
         self,
         experiment_name,
-        owner_subject_id: typing.Optional[str] = None,
         tenant_name: typing.Optional[str] = None,
     ):
         """
@@ -148,6 +147,9 @@ class AbstractStore:
         """
         pass
 
+    def hard_delete_experiment(self, experiment_id):
+        raise NotImplementedError()
+
     @abstractmethod
     def restore_experiment(self, experiment_id):
         """
@@ -426,11 +428,6 @@ class AbstractStore:
     ) -> typing.List[LatestRunLog]:
         raise NotImplementedError()
 
-    def list_experiment_ids_with_access_for_subject(
-        self, subject_type: SubjectType, subject_id: str, tenant_name: str
-    ) -> typing.List[str]:
-        raise NotImplementedError()
-
     # Mlfoundry Artifacts methods
     # TODO (chiragjn): consider moving these to another store/mlfoundry_artifacts/abstract_store.py
 
@@ -457,6 +454,7 @@ class AbstractStore:
     def get_artifact_by_id(
         self,
         artifact_id: uuid.UUID,
+        view_type: ViewType = ViewType.ACTIVE_ONLY,
     ) -> typing.Optional[Artifact]:
         raise NotImplementedError()
 
@@ -467,6 +465,12 @@ class AbstractStore:
     ) -> typing.Optional[Artifact]:
         raise NotImplementedError()
 
+    def delete_artifact_by_id(
+        self,
+        artifact_id: uuid.UUID,
+    ) -> None:
+        raise NotImplementedError()
+
     def list_artifacts(
         self,
         experiment_ids: typing.List[int],
@@ -573,6 +577,7 @@ class AbstractStore:
     def list_artifact_versions(
         self,
         artifact_id: uuid.UUID,
+        artifact_types: typing.Optional[typing.List[ArtifactType]] = None,
         statuses: typing.Optional[typing.List[ArtifactVersionStatus]] = None,
         max_results: typing.Optional[int] = None,
         page_token: typing.Optional[str] = None,
