@@ -340,15 +340,10 @@ class RestStore(AbstractStore):
     def get_experiment_by_name(
         self,
         experiment_name,
-        owner_subject_id: typing.Optional[str] = None,
         tenant_name: typing.Optional[str] = None,
     ):
         try:
-            req_body = message_to_json(
-                GetExperimentByName(
-                    experiment_name=experiment_name, owner_subject_id=owner_subject_id or ""
-                )
-            )
+            req_body = message_to_json(GetExperimentByName(experiment_name=experiment_name))
             response_proto = self._call_endpoint(GetExperimentByName, req_body)
             return Experiment.from_proto(response_proto.experiment)
         except MlflowException as e:
@@ -435,6 +430,7 @@ class RestStore(AbstractStore):
     def get_artifact_by_id(
         self,
         artifact_id: uuid.UUID,
+        **kwargs
     ) -> Artifact:
         message = mlfa_pb2.GetArtifact(id=str(artifact_id))
         request_body = message_to_json(message)
@@ -666,6 +662,42 @@ class RestStore(AbstractStore):
         response_proto = self._call_endpoint(mlfa_pb2.AddCustomMetricsToModelVersion, request_body)
         return ModelVersion.from_proto(response_proto.model_version)
 
+    def list_artifact_versions(
+        self,
+        artifact_id: uuid.UUID,
+        max_results: typing.Optional[int] = None,
+        page_token: typing.Optional[str] = None,
+        **kwargs,
+    ) -> PagedList[ArtifactVersion]:
+        message = mlfa_pb2.ListArtifactVersions(
+            artifact_id=str(artifact_id), max_results=max_results, page_token=page_token
+        )
+        request_body = message_to_json(message)
+        response_proto = self._call_endpoint(mlfa_pb2.ListArtifactVersions, request_body)
+        return PagedList(
+            [ArtifactVersion.from_proto(av) for av in response_proto.artifact_versions],
+            token=response_proto.next_page_token,
+            total=response_proto.total,
+        )
+
+    def list_model_versions(
+        self,
+        model_id: uuid.UUID,
+        max_results: typing.Optional[int] = None,
+        page_token: typing.Optional[str] = None,
+        **kwargs,
+    ) -> PagedList[ModelVersion]:
+        message = mlfa_pb2.ListModelVersions(
+            model_id=str(model_id), max_results=max_results, page_token=page_token
+        )
+        request_body = message_to_json(message)
+        response_proto = self._call_endpoint(mlfa_pb2.ListModelVersions, request_body)
+        return PagedList(
+            [ModelVersion.from_proto(mv) for mv in response_proto.model_versions],
+            token=response_proto.next_page_token,
+            total=response_proto.total,
+        )
+
 
 class DatabricksRestStore(RestStore):
     """
