@@ -34,6 +34,7 @@ from mlflow.entities import (
 from mlflow.exceptions import MlflowException
 from mlflow.protos.databricks_pb2 import INVALID_PARAMETER_VALUE, ErrorCode
 from mlflow.store.artifact.artifact_repository_registry import get_artifact_repository
+from mlflow.store.entities import PagedList
 from mlflow.store.tracking import SEARCH_MAX_RESULTS_DEFAULT
 from mlflow.store.tracking.abstract_store import AbstractStore
 from mlflow.tracking._tracking_service import utils
@@ -182,12 +183,12 @@ class TrackingServiceClient:
         """
         return self.store.get_experiment(experiment_id)
 
-    def get_experiment_by_name(self, name, owner_subject_id: typing.Optional[str] = None):
+    def get_experiment_by_name(self, name):
         """
         :param name: The experiment name.
         :return: :py:class:`mlflow.entities.Experiment`
         """
-        return self.store.get_experiment_by_name(name, owner_subject_id=owner_subject_id)
+        return self.store.get_experiment_by_name(name)
 
     def create_experiment(self, name, artifact_location=None, tags=None, description=None):
         """Create an experiment.
@@ -647,3 +648,25 @@ class TrackingServiceClient:
         return self.store.add_custom_metrics_to_model_version(
             version_id=version_id, custom_metrics=custom_metrics
         )
+
+    def list_artifact_versions(
+        self,
+        artifact_id: uuid.UUID,
+        max_results: typing.Optional[int] = None,
+        page_token: typing.Optional[str] = None,
+    ) -> PagedList[ArtifactVersion]:
+        return self.store.list_artifact_versions(
+            artifact_id=artifact_id,
+            max_results=max_results,
+            page_token=page_token,
+        )
+
+    def list_model_versions(
+        self,
+        model_id: uuid.UUID,
+        max_results: typing.Optional[int] = None,
+        page_token: typing.Optional[str] = None,
+    ) -> PagedList[ModelVersion]:
+        return self.store.list_model_versions(
+            model_id=model_id, max_results=max_results, page_token=page_token
+        )
