@@ -20,6 +20,7 @@ from mlflow.entities import (
     Artifact,
     ArtifactType,
     ArtifactVersion,
+    ArtifactVersionStatus,
     CustomMetric,
     Experiment,
     Feature,
@@ -396,14 +397,11 @@ class MlflowClient:
         """
         return self._tracking_client.get_experiment(experiment_id)
 
-    def get_experiment_by_name(
-        self, name: str, owner_subject_id: Optional[str] = None
-    ) -> Optional[Experiment]:
+    def get_experiment_by_name(self, name: str) -> Optional[Experiment]:
         """
         Retrieve an experiment by experiment name from the backend store
 
         :param name: The experiment name, which is case sensitive.
-               owner_subject_id: owner of the experiment
         :return: An instance of :py:class:`mlflow.entities.Experiment`
                  if an experiment with the specified name exists, otherwise None.
 
@@ -430,7 +428,7 @@ class MlflowClient:
             Artifact Location: file:///.../mlruns/0
             Lifecycle_stage: active
         """
-        return self._tracking_client.get_experiment_by_name(name, owner_subject_id=owner_subject_id)
+        return self._tracking_client.get_experiment_by_name(name)
 
     def create_experiment(
         self,
@@ -1880,3 +1878,25 @@ class MlflowClient:
         return self._tracking_client.add_custom_metrics_to_model_version(
             version_id=version_id, custom_metrics=custom_metrics
         )
+
+    def list_artifact_versions(
+        self,
+        artifact_id: uuid.UUID,
+        max_results: Optional[int] = None,
+        page_token: Optional[str] = None,
+    ) -> PagedList[ArtifactVersion]:
+        return self._tracking_client.list_artifact_versions(
+            artifact_id=artifact_id,
+            max_results=max_results,
+            page_token=page_token,
+        )
+
+    def list_model_versions(
+        self,
+        model_id: uuid.UUID,
+        max_results: Optional[int] = None,
+        page_token: Optional[str] = None,
+    ) -> PagedList[ModelVersion]:
+        return self._tracking_client.list_model_versions(
+            model_id=model_id, max_results=max_results, page_token=page_token
+        )
