@@ -169,7 +169,7 @@ def http_request_safe(host_creds, endpoint, method, **kwargs):
 
 def verify_rest_response(response, endpoint):
     """Verify the return code and format, raise exception if the request was not successful."""
-    if response.status_code != 200:
+    if response.status_code not in (200, 201):
         if _can_parse_as_json_object(response.text):
             raise RestException(json.loads(response.text))
         else:
